==> robovm-cocoatouch-1.8.0-sources.jar: org/robovm/apple/avfoundation/AVCaptureManualExposureBracketedStillImageSettings.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.avfoundation;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.corefoundation.*;
import org.robovm.apple.dispatch.*;
import org.robovm.apple.coreanimation.*;
import org.robovm.apple.coreimage.*;
import org.robovm.apple.coregraphics.*;
import org.robovm.apple.coreaudio.*;
import org.robovm.apple.coremedia.*;
import org.robovm.apple.corevideo.*;
import org.robovm.apple.mediatoolbox.*;
import org.robovm.apple.audiotoolbox.*;
import org.robovm.apple.audiounit.*;
/*</imports>*/

/*<javadoc>*/
/**
 * @since Available in iOS 8.0 and later.
 */
/*</javadoc>*/
/*<annotations>*/@Library("AVFoundation") @NativeClass/*</annotations>*/
/*<visibility>*/public/*</visibility>*/ class /*<name>*/AVCaptureManualExposureBracketedStillImageSettings/*</name>*/ 
    extends /*<extends>*/AVCaptureBracketedStillImageSettings/*</extends>*/ 
    /*<implements>*//*</implements>*/ {

    /*<ptr>*/public static class AVCaptureManualExposureBracketedStillImageSettingsPtr extends Ptr<AVCaptureManualExposureBracketedStillImageSettings, AVCaptureManualExposureBracketedStillImageSettingsPtr> {}/*</ptr>*/
    /*<bind>*/static { ObjCRuntime.bind(AVCaptureManualExposureBracketedStillImageSettings.class); }/*</bind>*/
    /*<constants>*//*</constants>*/
    /*<constructors>*/
    public AVCaptureManualExposureBracketedStillImageSettings() {}
    protected AVCaptureManualExposureBracketedStillImageSettings(SkipInit skipInit) { super(skipInit); }
    public AVCaptureManualExposureBracketedStillImageSettings(@ByVal CMTime duration, float ISO) { super(create(duration, ISO)); retain(getHandle()); }
    /*</constructors>*/
    /*<properties>*/
    @Property(selector = "exposureDuration")
    public native @ByVal CMTime getExposureDuration();
    @Property(selector = "ISO")
    public native float getISO();
    /*</properties>*/
    /*<members>*//*</members>*/
    /*<methods>*/
    @Method(selector = "manualExposureSettingsWithExposureDuration:ISO:")
    protected static native @Pointer long create(@ByVal CMTime duration, float ISO);
    /*</methods>*/
}

==> robovm-cocoatouch-2.3.16-sources.jar: org/robovm/apple/avfoundation/AVCaptureManualExposureBracketedStillImageSettings.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.avfoundation;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.corefoundation.*;
import org.robovm.apple.dispatch.*;
import org.robovm.apple.coreanimation.*;
import org.robovm.apple.coreimage.*;
import org.robovm.apple.coregraphics.*;
import org.robovm.apple.coreaudio.*;
import org.robovm.apple.coremedia.*;
import org.robovm.apple.corevideo.*;
import org.robovm.apple.mediatoolbox.*;
import org.robovm.apple.audiotoolbox.*;
/*</imports>*/

/*<javadoc>*/

/*</javadoc>*/
/*<annotations>*/@Library("AVFoundation") @NativeClass/*</annotations>*/
/*<visibility>*/public/*</visibility>*/ class /*<name>*/AVCaptureManualExposureBracketedStillImageSettings/*</name>*/ 
    extends /*<extends>*/AVCaptureBracketedStillImageSettings/*</extends>*/ 
    /*<implements>*//*</implements>*/ {

    /*<ptr>*/public static class AVCaptureManualExposureBracketedStillImageSettingsPtr extends Ptr<AVCaptureManualExposureBracketedStillImageSettings, AVCaptureManualExposureBracketedStillImageSettingsPtr> {}/*</ptr>*/
    /*<bind>*/static { ObjCRuntime.bind(AVCaptureManualExposureBracketedStillImageSettings.class); }/*</bind>*/
    /*<constants>*//*</constants>*/
    /*<constructors>*/
    protected AVCaptureManualExposureBracketedStillImageSettings() {}
    protected AVCaptureManualExposureBracketedStillImageSettings(Handle h, long handle) { super(h, handle); }
    protected AVCaptureManualExposureBracketedStillImageSettings(SkipInit skipInit) { super(skipInit); }
    public AVCaptureManualExposureBracketedStillImageSettings(@ByVal CMTime duration, float ISO) { super((Handle) null, create(duration, ISO)); retain(getHandle()); }
    /*</constructors>*/
    /*<properties>*/
    @Property(selector = "exposureDuration")
    public native @ByVal CMTime getExposureDuration();
    @Property(selector = "ISO")
    public native float getISO();
    /*</properties>*/
    /*<members>*//*</members>*/
    /*<methods>*/
    @Method(selector = "manualExposureSettingsWithExposureDuration:ISO:")
    protected static native @Pointer long create(@ByVal CMTime duration, float ISO);
    /*</methods>*/
}
